@@ -11,7 +11,6 @@
 */
 
 #include "pgm.h"
-#include <string.h>
 
 static int gethexit ARGS(( FILE* ifp ));
 
@@ -79,9 +78,8 @@ char *argv[];
     if ( cols <= 0 || rows <= 0 )
 	pm_error( "invalid header" );
     maxval = pm_bitstomaxval( depth );
-    if ( maxval > PGM_OVERALLMAXVAL )
-	pm_error( "depth %d is too large.  Our maximum is %d",
-              maxval, PGM_OVERALLMAXVAL);
+    if ( maxval > PGM_MAXMAXVAL )
+	pm_error( "depth is too large - try reconfiguring with PGM_BIGGRAYS" );
     if ( xcols != 0 && xrows != 0 && ( xcols != cols || xrows != rows ) )
 	{
 	float rowratio, colratio;
