@@ -10,7 +10,6 @@
 ** implied warranty.
 */
 
-#include <assert.h>
 #include "pgm.h"
 #include "dithers.h"
 
@@ -79,19 +78,10 @@ main( argc, argv )
 	    halftone = QT_CLUSTER8;
 	else if ( pm_keymatch( argv[argn], "-value", 2 ) )
 	{
-        /* Before 2001-06-08, this strtod() was a sscanf("%f").  Arjen
-           Bax found on his CYGWIN system this causes a comma to be
-           used as a decimal separator.  But on 2001-09.03, Charles
-           Wilson found this not to be the case.  
-        */
-	    char *ep;
 	    ++argn;
-	    if ( argn == argc
-		    || (fthreshval = strtod(argv[argn], &ep), *ep != 0)
-		    || fthreshval < 0.0 || fthreshval > 1.0 )
-	    {
+	    if ( argn == argc || sscanf( argv[argn], "%f", &fthreshval ) != 1 ||
+		fthreshval < 0.0 || fthreshval > 1.0 )
 		pm_usage( usage );
-	    }
 	}
 	else if ( pm_keymatch( argv[argn], "-clump", 2 ) )
 	{
@@ -129,12 +119,11 @@ main( argc, argv )
 	{
 	case QT_FS:
 	    /* Initialize Floyd-Steinberg error vectors. */
-	    overflow_add(cols, 2);
 	    thiserr = (long*) pm_allocrow( cols + 2, sizeof(long) );
 	    nexterr = (long*) pm_allocrow( cols + 2, sizeof(long) );
-	    srand( (int) ( time( 0 ) ^ getpid( ) ) );
+	    srandom( (int) ( time( 0 ) ^ getpid( ) ) );
 	    for ( col = 0; col < cols + 2; ++col )
-		thiserr[col] = ( rand( ) % FS_SCALE - HALF_FS_SCALE ) / 4;
+		thiserr[col] = ( random( ) % FS_SCALE - HALF_FS_SCALE ) / 4;
 	    /* (random errors in [-FS_SCALE/8 .. FS_SCALE/8]) */
 	    fs_direction = 1;
 	    threshval = fthreshval * FS_SCALE;
@@ -306,6 +295,7 @@ main( argc, argv )
     {
     	gray **grays;
     	bit **bits;
+	int xx,yy;
 	int end;
 	int *x,*y;
 	int sum = 0;
